# jmse.py [![Latest Version][pypi-shield]][pypi-link] [![Build Status][build-image]][build-link] [![Apache 2.0 License][license-image]][license-link]

Python implementation of JSON Message Signing and Encryption (JMSE):
An interoperable, minimalist signing and encryption format for serialized
JSON messages.

## Help and Discussion

Have questions? Want to suggest a feature or change?

* [Gitter]: web-based chat about **JMSE**
* [Google Group]: join via web or email ([jmse+subscribe@googlegroups.com])

## License

Copyright © 2019 JMSE Developers

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    https://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

## Contribution

Unless you explicitly state otherwise, any contribution intentionally
submitted for inclusion in the work by you shall be licensed as above,
without any additional terms or conditions.

[//]: # (badges)

[pypi-shield]: https://img.shields.io/pypi/v/jmse.svg
[pypi-link]: https://pypi.python.org/pypi/jmse/
[build-image]: https://secure.travis-ci.org/jmse-json/jmse.py.svg?branch=master
[build-link]: http://travis-ci.org/jmse-json/jmse.py
[license-image]: https://img.shields.io/badge/license-Apache2.0-blue.svg
[license-link]: https://github.com/jmse-json/jmse.js/blob/master/LICENSE

[//]: # (general links)

[Gitter]: https://gitter.im/jmse-json/Lobby
[Google Group]: https://groups.google.com/forum/#!forum/jmse
[jmse+subscribe@googlegroups.com]: mailto:jmse+subscribe@googlegroups.com
